@@ -12,7 +12,12 @@ use Helios::Job;
 use Helios::Service;
 use Helios::LogEntry::Levels ':all';
 
-our $VERSION = '2.31_0211';
+our $VERSION = '2.41';
+
+# FILE CHANGE HISTORY
+# 2011-12-15: Complete rewrite to allow requester to send job arg XML in an 
+# HTTP POST w/o form encoding.  Also, HELIOS_CLASS_MAP lookup is no longer 
+# necessary.
 
 # grab the CGI params (we may not have any)
 my $cgi = CGI->new();
@@ -148,7 +153,7 @@ HTML form as a guide:
  <br />
  <input type="submit" value="Submit Job" />
  </form>
- 
+
 The params field should contain the job arguments in XML format, like the 
 following example:
 
@@ -202,10 +207,10 @@ script as an example:
  ENDXML
 
  my $r = $ua->request(POST 'http://localhost/cgi-bin/submitJob.pl',
-		Content_Type => 'text/xml',
-		Content => $message
+ 		Content_Type => 'text/xml',
+ 		Content => $jobXML
  );
- print $response->as_string;
+ print $r->as_string;
 
 =head1 RESPONSE
 
