@@ -1,14 +1,19 @@
 package Helios;
 
 use 5.008000;
+use strict;
+use warnings;
 
-our $VERSION = '2.601_3750';
+our $VERSION = '2.801_3270';
 
 # 2011-12-07: Added Andrew Johnson copyright notices.
 # 2012-01-04: Reset all line length limits to 80.  
 # 2012-01-22: Edited summary to "a distributed job processing system."  
 # [LH] 2012-07-16:  Added Logical Helion, LLC and Six Apart Ltd copyright 
 # notices.
+# [LH] [2014-02-28]: Updated copyright info.
+# [LH] [2014-08-10]: Added strict and warnings pragmas to satisfy certain 
+# CPAN testing systems.
 
 =head1 NAME
 
@@ -48,7 +53,7 @@ Andrew Johnson, E<lt>lajandy at cpan dotorgE<gt>
 
 Copyright (C) 2008-9 by CEB Toolbox, Inc.
 
-Portions of this software are Copyright (C) 2012-3 by Logical Helion, LLC
+Portions of this software are Copyright (C) 2012-4 by Logical Helion, LLC
 where noted.
 
 Portions of this software are Copyright (C) 2009-12 by Andrew Johnson
@@ -70,4 +75,4 @@ This software comes with no warranty of any kind.
 
 =cut
 
-# 
\ No newline at end of file
+# 
